@@ -22,26 +22,21 @@ class SynDB(object):
         self.set_sigterm_handler()
 
     def load(self , location, auto_dump):
+       self.loco = location
+       self.auto_dump = auto_dump
        if os.path.exists(location):
            self._load()
-           self.loco = location
-           self.auto_dump = auto_dump
        else:
             self.db = {}
        return True
 
+    def _autodump(self):
+        if self.auto_dump:
+            self.dump()
+
     def _load(self):
         self.db = json.load(open(self.location , "r"))
 
-    def auto_dump(self):
-        return self._autodump()
-
-    def _autodump(self):
-        if self.auto_dump is True:
-            self.dump()
-        else:
-            pass
-
     def set_sigterm_handler(self):
          def sigterm_handler():
             if self.dthread is not None:
@@ -61,7 +56,7 @@ class SynDB(object):
         except:
             return False
 
-    def set(self , key: Union[str, int] , value):
+    def set(self , key, value):
         if isinstance(key, str):
             self.db[key] = value
             self._autodump()
@@ -103,4 +98,4 @@ class SynDB(object):
             return False
         else:
             print(self.db)
-            return True
+            return True
\ No newline at end of file
